<?php
/*
Plugin Name: DuckDuckGo Search Widget
Plugin URI: http://wordpress.org/extend/plugins/duckduckgo-search/
Description: Adds a DuckDuckGo search widget to your site.
Version: 0.1.1
Author: Samir Shah
Author URI: http://rayofsolaris.net/
License: GPLv2 or later
*/

if( !defined( 'ABSPATH' ) )
	exit;

class DuckDuckGoSearch {
	function __construct() {
		add_action( 'widgets_init', array( $this, 'register_widget' ) );
		if( !is_admin() ) {
			add_filter( 'query_vars', array( $this, 'filter_query_vars' ) );
			add_action( 'template_redirect', array( $this, 'search_redirect' ) );
		}
	}
	
	function filter_query_vars( $qvs ) {
		$qvs[] = 'ddg-s';
		return $qvs;
	}
	
	function register_widget() {
		register_widget( 'DuckDuckGoSearchWidget' );
	}
	
	function search_redirect() {
		if( ! $ddg = get_query_var( 'ddg-s' ) )
			return;

		$vars = array( 
			'q' => get_search_query( false ) . ' site:' . preg_replace( '#^https?://#', '', home_url( '/' ) ),
			'kf' => '-1',	// No favicons/WOT ratings for single site
			'ki' => '-1',	// No disambiguations
		);
		
		$scheme = ( $ddg == 'ssl' ) ? 'https' : 'http';
		wp_redirect( $scheme . '://duckduckgo.com/?' . http_build_query( $vars ) );
		exit;
	}
}

class DuckDuckGoSearchWidget extends WP_Widget {
	private $counter = 1;
	
	function __construct() {
		parent::__construct( 'duckduckgo', 'DuckDuckGo Search', array( 'classname' => 'widget_duckduckgo', 'description' => 'DuckDuckGo search form for your site.' ) );
	}

	function widget( $args, $instance ) {
		extract( $args );
		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

		echo $before_widget;
		if ( $title )
			echo $before_title . $title . $after_title;
		
		$id = $this->counter;
		$ssl = $instance['ssl'] ? 'ssl' : 'no-ssl';
		
		echo "<form role='search' method='get' class='duckduckgo-search' id='duckduckgo-search-$id' action='" . esc_url( home_url( '/' ) ) . "' ><div>
	<label class='screen-reader-text' for='duckduckgo-s-$id'>" . __('Search for:') . "</label>
	<input type='text' name='s' id='duckduckgo-s-$id' /><input type='hidden' name='ddg-s' value='$ssl' />
	<input type='submit' id='duckduckgo-submit-$id' value='" . __( 'Search' ) . "' />
	</div></form>";
		
		echo $after_widget;
		$this->counter += 1;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $new_instance;
		$instance['title'] = strip_tags( $instance['title'] );
		$instance['ssl'] = isset( $instance['ssl'] );
		return $instance;
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'ssl' => true, 'logo' => false ) );
		$title = array( 'val' => esc_attr( $instance['title'] ), 'id' => $this->get_field_id('title'), 'name' => $this->get_field_name('title') );
		$ssl = array( 'checked' => checked( $instance['ssl'], true, false ), 'id' => $this->get_field_id('ssl'), 'name' => $this->get_field_name('ssl') );
		
		echo "<p><label for='{$title['id']}'>" . __('Title:') . "</label> <input class='widefat' id='{$title['id']}' name='{$title['name']}' type='text' value='{$title['val']}' /></p>";
		echo "<p><label for='{$ssl['id']}'><input id='{$ssl['id']}' name='{$ssl['name']}' type='checkbox' {$ssl['checked']} /> " . __('Use SSL') . '</label></p>';
	}
}

new DuckDuckGoSearch();
